=======
Credits
=======

Development Lead
----------------

* Joe Schmid <jschmid@symphonyrm.com>

Contributors
------------

* Lara Stoll <lstoll@symphonyrm.com>
* Cassandra Teale <cteale@symphonyrm.com>
